aboutsummaryrefslogtreecommitdiff
path: root/MediaBrowser.Controller
diff options
context:
space:
mode:
authorLuke Pulverenti <luke.pulverenti@gmail.com>2013-12-04 15:55:42 -0500
committerLuke Pulverenti <luke.pulverenti@gmail.com>2013-12-04 15:55:42 -0500
commit81e59040d004cf75c254481fb023495347906330 (patch)
tree6cd5859355caf71b04605dd822206c5207a7d4c9 /MediaBrowser.Controller
parentcb882a4b48e9cf03cd363c54d93338ad62153e7e (diff)
updated live tv models
Diffstat (limited to 'MediaBrowser.Controller')
-rw-r--r--MediaBrowser.Controller/LiveTv/ILiveTvManager.cs10
-rw-r--r--MediaBrowser.Controller/LiveTv/ProgramInfo.cs21
-rw-r--r--MediaBrowser.Controller/LiveTv/RecordingInfo.cs19
-rw-r--r--MediaBrowser.Controller/LiveTv/TimerInfo.cs24
4 files changed, 53 insertions, 21 deletions
diff --git a/MediaBrowser.Controller/LiveTv/ILiveTvManager.cs b/MediaBrowser.Controller/LiveTv/ILiveTvManager.cs
index 4e73fc109..b8dfbe05d 100644
--- a/MediaBrowser.Controller/LiveTv/ILiveTvManager.cs
+++ b/MediaBrowser.Controller/LiveTv/ILiveTvManager.cs
@@ -12,6 +12,12 @@ namespace MediaBrowser.Controller.LiveTv
public interface ILiveTvManager
{
/// <summary>
+ /// Gets the active service.
+ /// </summary>
+ /// <value>The active service.</value>
+ ILiveTvService ActiveService { get; }
+
+ /// <summary>
/// Gets the services.
/// </summary>
/// <value>The services.</value>
@@ -37,7 +43,7 @@ namespace MediaBrowser.Controller.LiveTv
/// <param name="id">The identifier.</param>
/// <returns>Task.</returns>
Task CancelTimer(string id);
-
+
/// <summary>
/// Adds the parts.
/// </summary>
@@ -82,7 +88,7 @@ namespace MediaBrowser.Controller.LiveTv
/// <param name="cancellationToken">The cancellation token.</param>
/// <returns>Task{QueryResult{TimerInfoDto}}.</returns>
Task<QueryResult<TimerInfoDto>> GetTimers(TimerQuery query, CancellationToken cancellationToken);
-
+
/// <summary>
/// Gets the channel.
/// </summary>
diff --git a/MediaBrowser.Controller/LiveTv/ProgramInfo.cs b/MediaBrowser.Controller/LiveTv/ProgramInfo.cs
index cf5cdb94c..8059c1100 100644
--- a/MediaBrowser.Controller/LiveTv/ProgramInfo.cs
+++ b/MediaBrowser.Controller/LiveTv/ProgramInfo.cs
@@ -27,11 +27,12 @@ namespace MediaBrowser.Controller.LiveTv
/// </summary>
/// <value>The official rating.</value>
public string OfficialRating { get; set; }
-
+
/// <summary>
- /// Description of the progam.
+ /// Gets or sets the overview.
/// </summary>
- public string Description { get; set; }
+ /// <value>The overview.</value>
+ public string Overview { get; set; }
/// <summary>
/// The start date of the program, in UTC.
@@ -55,22 +56,22 @@ namespace MediaBrowser.Controller.LiveTv
public List<string> Genres { get; set; }
/// <summary>
- /// Gets or sets the quality.
- /// </summary>
- /// <value>The quality.</value>
- public ProgramVideoQuality Quality { get; set; }
-
- /// <summary>
/// Gets or sets the original air date.
/// </summary>
/// <value>The original air date.</value>
public DateTime? OriginalAirDate { get; set; }
/// <summary>
+ /// Gets or sets a value indicating whether this instance is hd.
+ /// </summary>
+ /// <value><c>true</c> if this instance is hd; otherwise, <c>false</c>.</value>
+ public bool? IsHD { get; set; }
+
+ /// <summary>
/// Gets or sets the audio.
/// </summary>
/// <value>The audio.</value>
- public ProgramAudio Audio { get; set; }
+ public ProgramAudio? Audio { get; set; }
/// <summary>
/// Gets or sets the community rating.
diff --git a/MediaBrowser.Controller/LiveTv/RecordingInfo.cs b/MediaBrowser.Controller/LiveTv/RecordingInfo.cs
index 2c8e8cb46..1ffbb7e23 100644
--- a/MediaBrowser.Controller/LiveTv/RecordingInfo.cs
+++ b/MediaBrowser.Controller/LiveTv/RecordingInfo.cs
@@ -37,11 +37,12 @@ namespace MediaBrowser.Controller.LiveTv
/// </summary>
/// <value>The path.</value>
public string Path { get; set; }
-
+
/// <summary>
- /// Description of the recording.
+ /// Gets or sets the overview.
/// </summary>
- public string Description { get; set; }
+ /// <value>The overview.</value>
+ public string Overview { get; set; }
/// <summary>
/// The start date of the recording, in UTC.
@@ -83,6 +84,18 @@ namespace MediaBrowser.Controller.LiveTv
public string EpisodeTitle { get; set; }
/// <summary>
+ /// Gets or sets a value indicating whether this instance is hd.
+ /// </summary>
+ /// <value><c>true</c> if this instance is hd; otherwise, <c>false</c>.</value>
+ public bool? IsHD { get; set; }
+
+ /// <summary>
+ /// Gets or sets the audio.
+ /// </summary>
+ /// <value>The audio.</value>
+ public ProgramAudio? Audio { get; set; }
+
+ /// <summary>
/// Gets or sets the official rating.
/// </summary>
/// <value>The official rating.</value>
diff --git a/MediaBrowser.Controller/LiveTv/TimerInfo.cs b/MediaBrowser.Controller/LiveTv/TimerInfo.cs
index 3df0b8cca..26e5869ce 100644
--- a/MediaBrowser.Controller/LiveTv/TimerInfo.cs
+++ b/MediaBrowser.Controller/LiveTv/TimerInfo.cs
@@ -59,15 +59,27 @@ namespace MediaBrowser.Controller.LiveTv
public RecordingStatus Status { get; set; }
/// <summary>
/// Gets or sets the pre padding seconds.
/// </summary>
- /// <value>The pre padding seconds.</value>
- public int PrePaddingSeconds { get; set; }
+ /// <value>The requested pre padding seconds.</value>
+ public int RequestedPrePaddingSeconds { get; set; }
/// <summary>
/// Gets or sets the post padding seconds.
/// </summary>
- /// <value>The post padding seconds.</value>
- public int PostPaddingSeconds { get; set; }
+ /// <value>The requested post padding seconds.</value>
+ public int RequestedPostPaddingSeconds { get; set; }
+
+ /// <summary>
+ /// Gets or sets the required pre padding seconds.
+ /// </summary>
+ /// <value>The required pre padding seconds.</value>
+ public int RequiredPrePaddingSeconds { get; set; }
+
+ /// <summary>
+ /// Gets or sets the required post padding seconds.
+ /// </summary>
+ /// <value>The required post padding seconds.</value>
+ public int RequiredPostPaddingSeconds { get; set; }
}
}
@@ -59,15 +59,27 @@ namespace MediaBrowser.Controller.LiveTv
public RecordingStatus Status { get; set; }
/// <summary>
- /// Gets or sets the pre padding seconds.
+ /// Gets or sets the requested pre padding seconds.
/// </summary>
@@ -59,15 +59,27 @@ namespace MediaBrowser.Controller.LiveTv
/// <summary>
- /// Gets or sets the post padding seconds.
+ /// Gets or sets the requested post padding seconds.
/// </summary>